@@ -11,63 +11,56 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib64/python3.7',
  'BLDLIBRARY': '-L. -lpython3.7dm',
- 'BLDSHARED': 'gcc -pthread -shared -Wl,-z,relro   -Wl,-z,now '
-              '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
-              '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
+ 'BLDSHARED': 'gcc -pthread -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  '
+              '-g',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-redhat-linux-gnu',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc -pthread',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
+ 'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1  '
            '-O2 -g -pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
-           '-grecord-gcc-switches '
-           '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-           '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
+           '-grecord-gcc-switches   -m64 -mtune=generic '
            '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv -O2 -g -pipe -Wall '
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv   -O2 -g -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
-           '-grecord-gcc-switches '
-           '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-           '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
+           '-grecord-gcc-switches   -m64 -mtune=generic '
            '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -flto '
-           '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none  -O2 -g '
-           '-pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
-           '-grecord-gcc-switches '
-           '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-           '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
-           '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -O0',
+           '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -Og',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -g -pipe -Wall -Werror=format-security '
                      '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                      '-fexceptions -fstack-protector-strong '
-                     '-grecord-gcc-switches '
-                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-                     '-mtune=generic -fasynchronous-unwind-tables '
-                     '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                     '-fPIC -fwrapv  -flto -fuse-linker-plugin '
-                     '-ffat-lto-objects -flto-partition=none',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                            '-Wno-unused-parameter '
+                     '-grecord-gcc-switches   -m64 -mtune=generic '
+                     '-fasynchronous-unwind-tables -fstack-clash-protection '
+                     '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv',
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -g -pipe -Wall -Werror=format-security '
+                            '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
+                            '-fexceptions -fstack-protector-strong '
+                            '-grecord-gcc-switches '
+                            '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                            '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 '
+                            '-m64 -mtune=generic -fasynchronous-unwind-tables '
+                            '-fstack-clash-protection -fcf-protection '
+                            '-D_GNU_SOURCE -fPIC -fwrapv -flto '
+                            '-fuse-linker-plugin -ffat-lto-objects '
+                            '-flto-partition=none -g -std=c99 -Wextra '
+                            '-Wno-unused-result -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wno-cast-function-type '
                             '-Werror=implicit-function-declaration',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-z,relro   -Wl,-z,now '
-                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
-                      '-fuse-linker-plugin -ffat-lto-objects '
-                      '-flto-partition=none',
+ 'CONFIGURE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g',
+ 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
+                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld '
+                             '-g  -flto -fuse-linker-plugin -ffat-lto-objects '
+                             '-flto-partition=none -g',
  'CONFIG_ARGS': "'--build=x86_64-redhat-linux-gnu' "
                 "'--host=x86_64-redhat-linux-gnu' '--program-prefix=' "
                 "'--disable-dependency-tracking' '--prefix=/usr' "
@@ -84,27 +77,24 @@ build_time_vars = {'ABIFLAGS': 'dm',
                 "'--with-ssl-default-suites=openssl' '--with-valgrind' "
                 "'--without-ensurepip' '--with-pydebug' "
                 "'build_alias=x86_64-redhat-linux-gnu' "
-                "'host_alias=x86_64-redhat-linux-gnu' 'CFLAGS=-O2 -g -pipe "
+                "'host_alias=x86_64-redhat-linux-gnu' 'CFLAGS= -O2 -g -pipe "
                 '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
-                '-fstack-protector-strong -grecord-gcc-switches '
-                '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                '-fstack-protector-strong -grecord-gcc-switches   -m64 '
                 '-mtune=generic -fasynchronous-unwind-tables '
                 '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-                "-fwrapv ' 'LDFLAGS=-Wl,-z,relro   -Wl,-z,now "
-                "-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g ' "
-                "'CPPFLAGS=' "
+                "-fwrapv ' 'LDFLAGS= -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  "
+                "-g ' 'CPPFLAGS=' "
                 "'PKG_CONFIG_PATH=:/usr/lib64/pkgconfig:/usr/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.7dm',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.0/build/debug/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.0/build/debug/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.3/build/debug/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.3/build/debug/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.7.0/Include',
+             '-I/builddir/build/BUILD/Python-3.7.3/Include',
  'CXX': 'g++ -pthread',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.7 '
              '/usr/lib64/python3.7/lib-dynload',
@@ -176,6 +166,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
  'HAVE_CRYPT_H': 1,
+ 'HAVE_CRYPT_R': 1,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 0,
  'HAVE_CURSES_FILTER': 1,
@@ -285,7 +276,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'HAVE_GETSPNAM': 1,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
- 'HAVE_GLIBC_MEMMOVE_BUG': 1,
+ 'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
  'HAVE_HTOLE64': 1,
@@ -555,15 +546,12 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-Wl,-z,relro   -Wl,-z,now '
-            '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
-            '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
+ 'LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g',
  'LDLAST': '',
  'LDLIBRARY': 'libpython3.7dm.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -Wl,-z,relro   -Wl,-z,now '
-             '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
-             '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
+ 'LDSHARED': 'gcc -pthread -shared -Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  '
+             '-g',
  'LDVERSION': '3.7dm',
  'LIBC': '',
  'LIBDEST': '/usr/lib64/python3.7',
@@ -577,7 +565,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'LIBRARY': 'libpython3.7dm.a',
  'LIBRARY_OBJS': '\\',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
- 'LIBS': '-lpthread -ldl  -lutil',
+ 'LIBS': '-lcrypt -lpthread -ldl  -lutil',
  'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
  'LINKCC': 'gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
@@ -595,7 +583,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.0/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.3/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -626,11 +614,10 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -O2 -g -pipe -Wall '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2 -g -pipe -Wall '
         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
         '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
-        '-grecord-gcc-switches -specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 -mtune=generic '
+        '-grecord-gcc-switches   -m64 -mtune=generic '
         '-fasynchronous-unwind-tables -fstack-clash-protection -fcf-protection '
         '-D_GNU_SOURCE -fPIC -fwrapv',
  'OTHER_LIBTOOL_OPT': '',
@@ -664,47 +651,79 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'PYTHON_FOR_REGEN': 'python3.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2 -g -pipe '
+                             '-Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                             '-fstack-protector-strong -grecord-gcc-switches   '
+                             '-m64 -mtune=generic -fasynchronous-unwind-tables '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-D_GNU_SOURCE -fPIC -fwrapv   -O2 -g -pipe -Wall '
+                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                             '-fstack-protector-strong -grecord-gcc-switches   '
+                             '-m64 -mtune=generic -fasynchronous-unwind-tables '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-D_GNU_SOURCE -fPIC -fwrapv  -Og -O2 -g -pipe '
+                             '-Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
+                             '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                             '-fstack-protector-strong -grecord-gcc-switches '
+                             '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                             '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 '
+                             '-m64 -mtune=generic -fasynchronous-unwind-tables '
+                             '-fstack-clash-protection -fcf-protection '
+                             '-D_GNU_SOURCE -fPIC -fwrapv -flto '
+                             '-fuse-linker-plugin -ffat-lto-objects '
+                             '-flto-partition=none -g -std=c99 -Wextra '
+                             '-Wno-unused-result -Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wno-cast-function-type '
+                             '-Werror=implicit-function-declaration -IObjects '
+                             '-IInclude -IPython -I. '
+                             '-I/builddir/build/BUILD/Python-3.7.3/Include '
+                             '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -O2 -g -pipe -Wall '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2 -g -pipe -Wall '
               '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
               '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
-              '-grecord-gcc-switches '
-              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-              '-mtune=generic -fasynchronous-unwind-tables '
-              '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-              '-fwrapv -O2 -g -pipe -Wall -Werror=format-security '
-              '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
-              '-fstack-protector-strong -grecord-gcc-switches '
-              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-              '-mtune=generic -fasynchronous-unwind-tables '
-              '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-              '-fwrapv  -flto -fuse-linker-plugin -ffat-lto-objects '
-              '-flto-partition=none  -O2 -g -pipe -Wall '
-              '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+              '-grecord-gcc-switches   -m64 -mtune=generic '
+              '-fasynchronous-unwind-tables -fstack-clash-protection '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv   -O2 -g -pipe '
+              '-Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
               '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions -fstack-protector-strong '
-              '-grecord-gcc-switches '
-              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-              '-mtune=generic -fasynchronous-unwind-tables '
-              '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE -fPIC '
-              '-fwrapv  -O0',
- 'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
-                     '-Wno-unused-parameter -Wno-missing-field-initializers '
-                     '-Wno-cast-function-type '
+              '-grecord-gcc-switches   -m64 -mtune=generic '
+              '-fasynchronous-unwind-tables -fstack-clash-protection '
+              '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -Og',
+ 'PY_CFLAGS_NODIST': '-O2 -g -pipe -Wall -Werror=format-security '
+                     '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
+                     '-fexceptions -fstack-protector-strong '
+                     '-grecord-gcc-switches '
+                     '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
+                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                     '-mtune=generic -fasynchronous-unwind-tables '
+                     '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
+                     '-fPIC -fwrapv -flto -fuse-linker-plugin '
+                     '-ffat-lto-objects -flto-partition=none -g -std=c99 '
+                     '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wno-cast-function-type '
                      '-Werror=implicit-function-declaration',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -O2 -g -pipe -Wall '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2 -g -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
-                   '-fstack-protector-strong -grecord-gcc-switches '
-                   '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
+                   '-fstack-protector-strong -grecord-gcc-switches   -m64 '
                    '-mtune=generic -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                   '-fPIC -fwrapv -O2 -g -pipe -Wall -Werror=format-security '
+                   '-fPIC -fwrapv   -O2 -g -pipe -Wall -Werror=format-security '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
+                   '-fexceptions -fstack-protector-strong '
+                   '-grecord-gcc-switches   -m64 -mtune=generic '
+                   '-fasynchronous-unwind-tables -fstack-clash-protection '
+                   '-fcf-protection -D_GNU_SOURCE -fPIC -fwrapv  -Og -O2 -g '
+                   '-pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-fexceptions -fstack-protector-strong '
                    '-grecord-gcc-switches '
@@ -712,31 +731,42 @@ build_time_vars = {'ABIFLAGS': 'dm',
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                    '-mtune=generic -fasynchronous-unwind-tables '
                    '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                   '-fPIC -fwrapv  -flto -fuse-linker-plugin -ffat-lto-objects '
-                   '-flto-partition=none  -O2 -g -pipe -Wall '
-                   '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                   '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
-                   '-fstack-protector-strong -grecord-gcc-switches '
-                   '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                   '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-                   '-mtune=generic -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -fcf-protection -D_GNU_SOURCE '
-                   '-fPIC -fwrapv  -O0 -std=c99 -Wextra -Wno-unused-result '
-                   '-Wno-unused-parameter -Wno-missing-field-initializers '
-                   '-Wno-cast-function-type '
+                   '-fPIC -fwrapv -flto -fuse-linker-plugin -ffat-lto-objects '
+                   '-flto-partition=none -g -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
+                   '-Wno-missing-field-initializers -Wno-cast-function-type '
                    '-Werror=implicit-function-declaration -IObjects -IInclude '
-                   '-IPython -I. -I/builddir/build/BUILD/Python-3.7.0/Include '
+                   '-IPython -I. -I/builddir/build/BUILD/Python-3.7.3/Include '
                    '-DPy_BUILD_CORE',
+ 'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g -Wl,-z,relro '
+                    '-Wl,--as-needed  -Wl,-z,now '
+                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+                    '-fuse-linker-plugin -ffat-lto-objects '
+                    '-flto-partition=none -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.7.0/Include',
+                '-I/builddir/build/BUILD/Python-3.7.3/Include',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_LDFLAGS': '-Wl,-z,relro   -Wl,-z,now '
-               '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
-               '-fuse-linker-plugin -ffat-lto-objects -flto-partition=none',
+ 'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g',
+ 'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
+                      '-specs=/usr/lib/rpm/redhat/redhat-hardened-ld -g  -flto '
+                      '-fuse-linker-plugin -ffat-lto-objects '
+                      '-flto-partition=none -g',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -O2 -g -pipe -Wall '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2 -g -pipe -Wall '
+                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                        '-fstack-protector-strong -grecord-gcc-switches   -m64 '
+                        '-mtune=generic -fasynchronous-unwind-tables '
+                        '-fstack-clash-protection -fcf-protection '
+                        '-D_GNU_SOURCE -fPIC -fwrapv   -O2 -g -pipe -Wall '
+                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
+                        '-fstack-protector-strong -grecord-gcc-switches   -m64 '
+                        '-mtune=generic -fasynchronous-unwind-tables '
+                        '-fstack-clash-protection -fcf-protection '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -Og -O2 -g -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
                         '-fstack-protector-strong -grecord-gcc-switches '
@@ -744,32 +774,14 @@ build_time_vars = {'ABIFLAGS': 'dm',
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
                         '-mtune=generic -fasynchronous-unwind-tables '
                         '-fstack-clash-protection -fcf-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -O2 -g -pipe -Wall '
-                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
-                        '-fstack-protector-strong -grecord-gcc-switches '
-                        '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-                        '-mtune=generic -fasynchronous-unwind-tables '
-                        '-fstack-clash-protection -fcf-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -flto '
-                        '-fuse-linker-plugin -ffat-lto-objects '
-                        '-flto-partition=none  -O2 -g -pipe -Wall '
-                        '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-                        '-Wp,-D_GLIBCXX_ASSERTIONS -fexceptions '
-                        '-fstack-protector-strong -grecord-gcc-switches '
-                        '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
-                        '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1 -m64 '
-                        '-mtune=generic -fasynchronous-unwind-tables '
-                        '-fstack-clash-protection -fcf-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -O0 -std=c99 -Wextra '
-                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -flto -fuse-linker-plugin '
+                        '-ffat-lto-objects -flto-partition=none -g -std=c99 '
+                        '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Wno-cast-function-type '
                         '-Werror=implicit-function-declaration -IObjects '
                         '-IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.7.0/Include',
- 'PY_WARN_ON_C_LOCALE': 1,
+                        '-I/builddir/build/BUILD/Python-3.7.3/Include',
  'Py_DEBUG': 1,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -777,12 +789,12 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.0/build/debug',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/debug',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lpthread -ldl  -lutil',
+ 'SHLIBS': '-lcrypt -lpthread -ldl  -lutil',
  'SHLIB_SUFFIX': '.so',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -806,7 +818,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37dm-x86_64-linux-gnu',
  'SRCDIRS': 'Parser Objects Python Modules Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.0/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.3/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -819,10 +831,10 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.0/build/debug '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/debug '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.0/build/debug '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/debug '
                './python /Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -831,10 +843,10 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.7 '
-                '/builddir/build/BUILD/Python-3.7.0/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.7.3/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.7',
- 'VPATH': '/builddir/build/BUILD/Python-3.7.0',
+ 'VPATH': '/builddir/build/BUILD/Python-3.7.3',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
@@ -845,9 +857,9 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.7.0/build/debug',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.0',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.7.3/build/debug',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.3',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.7.0'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.7.3'}
